==> core-react-0.7.1.tgz: package/es/Upload/index.js <==
function _typeof(obj) { "@babel/helpers - typeof"; if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } return _assertThisInitialized(self); }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import React from 'react';
import PropTypes from 'prop-types';
import cx from 'classnames';
import xhr from '../_utils/xhr';
import FileList from './FileList';
import Button from '../Button/index';


var Upload = /*#__PURE__*/function (_React$Component) {
  _inherits(Upload, _React$Component);

  function Upload() {
    var _this;

    _classCallCheck(this, Upload);

    _this = _possibleConstructorReturn(this, _getPrototypeOf(Upload).call(this));

    _defineProperty(_assertThisInitialized(_this), "handleClick", function (e) {
      var fileEl = _this.refs.file;
      fileEl.value = '';
      fileEl.click();
    });

    _defineProperty(_assertThisInitialized(_this), "handleChange", function (event) {
      var el = event.target;
      var files = el.files;
      var onUplading = _this.props.onUplading;
      var onUpload = _this.props.onUpload;
      onUplading && onUplading(0);
      onUpload ? onUpload(files) : _this.upload(files);
      el.value = '';
    });

    _defineProperty(_assertThisInitialized(_this), "handleRemove", function (currItem) {
      var self = _assertThisInitialized(_this);

      var arr = _this.state.list.slice(0);

      arr.map(function (item, index) {
        if (item === currItem) {
          arr.splice(index, 1);
          self.setState({
            list: arr
          });
        }
      });
    });

    _this.state = {
      data: {},
      list: []
    };
    return _this;
  }

  _createClass(Upload, [{
    key: "upload",
    value: function upload(files) {
      var onUplading = this.props.onUplading;
      var self = this;
      var arr = [];

      for (var i = 0; i < files.length; i++) {
        var file = files[i];
        arr.push({
          name: file.name,
          size: file.size,
          type: file.type,
          state: 0
        });

        (function (self, file, index) {
          var fd = new FormData();
          fd.append(self.props.fileName || 'files', file);
          xhr({
            type: 'post',
            url: self.props.action,
            data: fd,
            beforeSend: function beforeSend(xhr) {
              // Detect the current attachment uploading situation
              xhr.upload.onprogress = function (evt) {
                var loaded = evt.loaded;
                var tot = evt.total;
                var per = Math.floor(100 * loaded / tot); // Percentage that has been uploaded

                var list = self.state.list.slice(0);
                var f = list[index];
                f.percent = per;
                onUplading && onUplading(per);
                self.setState({
                  list: list
                });
              };
            },
            success: function success(data) {
              var list = self.state.list.slice(0);
              var f = list[index];
              f.state = 1;
              self.setState({
                data: data,
                list: list
              });

              if (typeof self.props.onComplete === 'function') {
                self.props.onComplete(data, list);
              }
            },
            error: function error(msg) {
              var list = self.state.list.slice(0);
              var f = list[index];
              f.state = 2;
              self.setState({
                list: list
              });

              if (typeof self.props.onComplete === 'function') {
                self.props.onComplete(msg, list);
              }
            },
            complete: function complete() {}
          });
        })(self, file, i);
      }

      this.setState({
        list: arr
      });
    }
  }, {
    key: "render",
    value: function render() {
      var _this$props = this.props,
          className = _this$props.className,
          action = _this$props.action,
          fileName = _this$props.fileName,
          multiple = _this$props.multiple,
          onUplading = _this$props.onUplading,
          onComplete = _this$props.onComplete,
          showFileList = _this$props.showFileList,
          button = _this$props.button,
          onUpload = _this$props.onUpload,
          other = _objectWithoutProperties(_this$props, ["className", "action", "fileName", "multiple", "onUplading", "onComplete", "showFileList", "button", "onUpload"]);

      return React.createElement("div", _extends({
        className: cx("".concat("waui", "-upload"), className)
      }, other), React.createElement("input", {
        ref: "file",
        onChange: this.handleChange,
        type: "file",
        multiple: !!multiple,
        style: {
          display: 'none'
        }
      }), React.createElement("div", {
        className: "".concat("waui", "-upload__children"),
        onClick: this.handleClick
      }, this.props.children), button && button.name && React.createElement(Button, _extends({}, button, {
        onClick: this.handleClick
      }), button.name), showFileList && React.createElement("div", {
        className: "".concat("waui", "-upload__listbox")
      }, React.createElement(FileList, {
        data: this.state.list,
        onRemove: this.handleRemove
      })));
    }
  }]);

  return Upload;
}(React.Component);

Upload.propTypes = {
  children: PropTypes.node,
  className: PropTypes.string,

  /** The url of uploading */
  action: PropTypes.string,

  /** The configuration of button for uploading */
  button: PropTypes.shape({
    name: PropTypes.string.isRequired,
    type: PropTypes.string,
    size: PropTypes.string,
    icon: PropTypes.string,
    circle: PropTypes.bool,
    transparent: PropTypes.bool
  }),

  /** The name of uploaded file, default value is `files` */
  fileName: PropTypes.string,

  /** Whether to support multi-selection, ie10+ supports, press ctrl can select multi files after enabled。 */
  multiple: PropTypes.bool,

  /** The callback of the progress of uploading */
  onUplading: PropTypes.func,
  onUpload: PropTypes.func,

  /** The callback of having uploaded, it works if the user does not have a custom onUpload method */
  onComplete: PropTypes.func,

  /** Whether to show file list */
  showFileList: PropTypes.bool
};
export default Upload;

==> core-react-0.8.0.tgz: package/es/Upload/index.js <==
function _typeof(obj) { "@babel/helpers - typeof"; if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } return _assertThisInitialized(self); }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import React from 'react';
import PropTypes from 'prop-types';
import cx from 'classnames';
import xhr from '../_utils/xhr';
import FileList from './FileList';
import Button from '../Button/index';


var Upload = /*#__PURE__*/function (_React$Component) {
  _inherits(Upload, _React$Component);

  function Upload() {
    var _this;

    _classCallCheck(this, Upload);

    _this = _possibleConstructorReturn(this, _getPrototypeOf(Upload).call(this));

    _defineProperty(_assertThisInitialized(_this), "handleClick", function (e) {
      var fileEl = _this.refs.file;
      fileEl.value = '';
      fileEl.click();
    });

    _defineProperty(_assertThisInitialized(_this), "handleChange", function (event) {
      var el = event.target;
      var files = el.files;
      var onUploading = _this.props.onUploading;
      var onUpload = _this.props.onUpload;
      onUploading && onUploading(0);
      onUpload ? onUpload(files) : _this.upload(files);
      el.value = '';
    });

    _defineProperty(_assertThisInitialized(_this), "handleRemove", function (currItem) {
      var self = _assertThisInitialized(_this);

      var arr = _this.state.list.slice(0);

      arr.map(function (item, index) {
        if (item === currItem) {
          arr.splice(index, 1);
          self.setState({
            list: arr
          });
        }
      });
    });

    _this.state = {
      data: {},
      list: []
    };
    return _this;
  }

  _createClass(Upload, [{
    key: "upload",
    value: function upload(files) {
      var onUploading = this.props.onUploading;
      var self = this;
      var arr = [];

      for (var i = 0; i < files.length; i++) {
        var file = files[i];
        arr.push({
          name: file.name,
          size: file.size,
          type: file.type,
          state: 0
        });

        (function (self, file, index) {
          var fd = new FormData();
          fd.append(self.props.fileName || 'files', file);
          xhr({
            type: 'post',
            url: self.props.action,
            data: fd,
            beforeSend: function beforeSend(xhr) {
              // Detect the current attachment uploading situation
              xhr.upload.onprogress = function (evt) {
                var loaded = evt.loaded;
                var tot = evt.total;
                var per = Math.floor(100 * loaded / tot); // Percentage that has been uploaded

                var list = self.state.list.slice(0);
                var f = list[index];
                f.percent = per;
                onUploading && onUploading(per);
                self.setState({
                  list: list
                });
              };
            },
            success: function success(data) {
              var list = self.state.list.slice(0);
              var f = list[index];
              f.state = 1;
              self.setState({
                data: data,
                list: list
              });

              if (typeof self.props.onComplete === 'function') {
                self.props.onComplete(data, list);
              }
            },
            error: function error(msg) {
              var list = self.state.list.slice(0);
              var f = list[index];
              f.state = 2;
              self.setState({
                list: list
              });

              if (typeof self.props.onComplete === 'function') {
                self.props.onComplete(msg, list);
              }
            },
            complete: function complete() {}
          });
        })(self, file, i);
      }

      this.setState({
        list: arr
      });
    }
  }, {
    key: "render",
    value: function render() {
      var _this$props = this.props,
          className = _this$props.className,
          action = _this$props.action,
          fileName = _this$props.fileName,
          multiple = _this$props.multiple,
          onUploading = _this$props.onUploading,
          onComplete = _this$props.onComplete,
          showFileList = _this$props.showFileList,
          button = _this$props.button,
          onUpload = _this$props.onUpload,
          other = _objectWithoutProperties(_this$props, ["className", "action", "fileName", "multiple", "onUploading", "onComplete", "showFileList", "button", "onUpload"]);

      return React.createElement("div", _extends({
        className: cx("".concat("waui", "-upload"), className)
      }, other), React.createElement("input", {
        ref: "file",
        onChange: this.handleChange,
        type: "file",
        multiple: !!multiple,
        style: {
          display: 'none'
        }
      }), React.createElement("div", {
        className: "".concat("waui", "-upload__children"),
        onClick: this.handleClick
      }, this.props.children), button && button.name && React.createElement(Button, _extends({}, button, {
        onClick: this.handleClick
      }), button.name), showFileList && React.createElement("div", {
        className: "".concat("waui", "-upload__listbox")
      }, React.createElement(FileList, {
        data: this.state.list,
        onRemove: this.handleRemove
      })));
    }
  }]);

  return Upload;
}(React.Component);

Upload.propTypes = {
  children: PropTypes.node,
  className: PropTypes.string,

  /** The url of uploading */
  action: PropTypes.string,

  /** The configuration of button for uploading */
  button: PropTypes.shape({
    name: PropTypes.string.isRequired,
    type: PropTypes.string,
    size: PropTypes.string,
    icon: PropTypes.string,
    circle: PropTypes.bool,
    transparent: PropTypes.bool
  }),

  /** The name of uploaded file, default value is `files` */
  fileName: PropTypes.string,

  /** Whether to support multi-selection, ie10+ supports, press ctrl can select multi files after enabled */
  multiple: PropTypes.bool,

  /** The callback of the progress of uploading */
  onUploading: PropTypes.func,
  onUpload: PropTypes.func,

  /** The callback of having uploaded, it works if the user does not have a custom onUpload method */
  onComplete: PropTypes.func,

  /** Whether to show file list */
  showFileList: PropTypes.bool
};
export default Upload;
